@@ -78,7 +78,7 @@ function(taskWindow)
       
       #update n in menu bar
       tkdelete(topMenu,0,1)  
-      tkadd(topMenu,"cascade",label=paste("#Interim times: K=",as.character(n)),menu=nMenu)
+      tkadd(topMenu,"cascade",label=paste("#Interim Times: K=",as.character(n)),menu=nMenu)
       
       ### equally or unequally spaced times? get it from the checkbox ###
       equallySpacedTimesInput <- as.logical(as.numeric(tclvalue(equallySpacedTimesCheckBoxValue)))
@@ -562,7 +562,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
         if(interimTimesBad)
         {
           readyForCalculate <- FALSE
-          tkmessageBox(message="Bad interim Times entered - old Times are kept so far! ",icon="error",type="ok")
+          tkmessageBox(message="Bad Interim Times entered - old Times are kept so far! ",icon="error",type="ok")
         }
         ##else take new times
         else
@@ -571,6 +571,13 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
         }
       
     }#end <--*if(equallySpacedTimesInput)* 
+    else
+    {
+     for(i in 1:n)
+     {
+       t[i]<<-i/n
+     }
+    }
     
     ##if user typed in second time scales - get them and
     ##check them to be in intervall(0,1] and in right order
@@ -606,6 +613,8 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
     
     if(readyForCalculate)
     {
+      # second time scale is not used so far --> set t2=t
+      t2<-t
       calculateTask1(n,t,t2,equallySpacedTimesInput,secondTimeScaleIsUsedInput, BoundsSymmetry, c(alpha1,alpha2),
                      c(phi1,phi2), c(function1,function2),TruncateBoundsInput, taskWindow)
     }
@@ -625,7 +634,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   
   #Set Toplevel
   task1 <- tktoplevel(taskWindow)
-  tkwm.title(task1,"-1- Compute bounds")
+  tkwm.title(task1,"-1- Compute Bounds")
   
   #Define main Frame
   InputTask1 <- tkframe(task1, relief="groove",borderwidth=2)
@@ -664,7 +673,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   tkadd(nMenu,"command",label="23",command=function() onChangeInterimAnalyses(23))
   tkadd(nMenu,"command",label="24",command=function() onChangeInterimAnalyses(24))
   tkadd(nMenu,"command",label="25",command=function() onChangeInterimAnalyses(25))
-  tkadd(topMenu,"cascade",label=paste("#Interim times: K= ",as.character(n)),menu=nMenu)
+  tkadd(topMenu,"cascade",label=paste("#Interim Times: K= ",as.character(n)),menu=nMenu)
   
   tkgrid(tklabel(InputTask1,text="")) # Blank line
    
@@ -725,7 +734,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   tkconfigure(asymmetric,variable=SymmetryValue,value="3")
   
   #grid labels and buttons together
-  tkgrid(tklabel(boundsLabelFrame,text="One-, Two-sided symmetric or asymmetric bounds?"),sticky="w")
+  tkgrid(tklabel(boundsLabelFrame,text="One-, Two-Sided-Symmetric or Asymmetric Bounds?"),sticky="w")
   tkgrid(tklabel(boundsRadioButtonFrame,text="One-Sided "),oneSided)
   tkgrid(tklabel(boundsRadioButtonFrame,text="Two-Sided "),twoSided)
   tkgrid(tklabel(boundsRadioButtonFrame,text="Asymmetric "),asymmetric)
@@ -765,7 +774,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   functionLabel1of1<-tklabel(functionsFrame1of1,text="What function should be used?")
   listBoxFunction1of1<-tklistbox(functionsFrame1of1,height=5,width=30,selectmode="single",background="grey")
   functionChoice1of1 <- c("(1) O'Brien-Fleming Type","(2) Pocock Type",
-    "(3) Power family: alpha* t^phi","(4) Hwang-Shih-DeCani family","(5) Exact Pocock Bounds")
+    "(3) Power Family: alpha* t^phi","(4) Hwang-Shih-DeCani Family","(5) Exact Pocock Bounds")
   for (i in (1:5))
   {
     tkinsert(listBoxFunction1of1,"end",functionChoice1of1[i])
@@ -828,7 +837,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   functionLabel1of2<-tklabel(functionsFrame1of2,text="Choose Function for UPPER Bounds")
   listBoxFunction1of2<-tklistbox(functionsFrame1of2,height=5,width=30,selectmode="single",background="grey")
   functionChoice1of2 <- c("(1) O'Brien-Fleming Type","(2) Pocock Type",
-    "(3) Power family: alpha* t^phi","(4) Hwang-Shih-DeCani family","(5) Pocock - the real Pocock Bounds")
+    "(3) Power Family: alpha* t^phi","(4) Hwang-Shih-DeCani Family","(5) Exact Pocock Bounds")
   for (i in (1:5))
   {
     tkinsert(listBoxFunction1of2,"end",functionChoice1of2[i])
@@ -847,7 +856,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   functionLabel2of2<-tklabel(functionsFrame2of2,text="Choose Function for LOWER Bounds")
   listBoxFunction2of2<-tklistbox(functionsFrame2of2,height=5,width=30,selectmode="single",background="grey")
   functionChoice2of2 <- c("(1) O'Brien-Fleming Type","(2) Pocock Type",
-    "(3) Power family: alpha* t^phi","(4) Hwang-Shih-DeCani family","(5) Pocock - the real Pocock Bounds")
+    "(3) Power Family: alpha* t^phi","(4) Hwang-Shih-DeCani Family","(5) Exact Pocock Bounds")
   for (i in (1:5))
   {
     tkinsert(listBoxFunction2of2,"end",functionChoice2of2[i])
@@ -910,7 +919,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   entry.truncationValue <-tkentry(TruncateDynamicFrame,width="3",textvariable=boundsTruncation)
     
   #put frames
-  tkgrid(tklabel(TruncateLabelFrame,text="Truncate standarized Bounds?"),TruncateBoundsCheckBox)
+  tkgrid(tklabel(TruncateLabelFrame,text="Truncate Standardized Bounds?"),TruncateBoundsCheckBox)
   tkgrid(boundsTruncationLabel,entry.truncationValue,sticky="w")
   tkgrid(TruncateLabelFrame,TruncateDynamicFrame,sticky="w")
   tkgrid(TruncateBoundsFrame,sticky="w")
