@@ -95,7 +95,7 @@ function(taskWindow)
       
       #update n in menu bar
       tkdelete(topMenu,0,1)  
-      tkadd(topMenu,"cascade",label=paste("#Interim times: K=",as.character(n)),menu=nMenu)
+      tkadd(topMenu,"cascade",label=paste("#Interim Times: K=",as.character(n)),menu=nMenu)
       
       ### equally or unequally spaced times? get it from the checkbox ###
       equallySpacedTimesInput <- as.logical(as.numeric(tclvalue(equallySpacedTimesCheckBoxValue)))
@@ -807,7 +807,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
         if(interimTimesBad)
         {
           readyForCalculate <- FALSE
-          tkmessageBox(message="Bad interim Times entered - old Times are kept so far! ",icon="error",type="ok")
+          tkmessageBox(message="Bad Interim Times entered - old Times are kept so far! ",icon="error",type="ok")
         }
         ##else take new times
         else
@@ -816,6 +816,13 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
         }
       
     }#end <--*if(equallySpacedTimesInput)* 
+    else
+    {
+     for(i in 1:n)
+     {
+       t[i]<<-i/n
+     }
+    }
     
     ##if user typed in second time scales - get them and
     ##check them to be in intervall(0,1] and in right order
@@ -870,7 +877,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
         ##If t[n]=1, t2[n] is maximum of t2. 
         if(t[n]==1)
         {
-         tkmessageBox(title="-2- Compute drift given power and bounds",message="Second Time scale will be used to determine covariances.",icon="info",type="ok")
+         tkmessageBox(title="-2- Compute Drift given Power and Bounds",message="Second Time scale will be used to determine covariances.",icon="info",type="ok")
          t2max<<-t2[n] 
          t3<<-t2/t2max
         }
@@ -984,6 +991,8 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
      
     if(readyForCalculate)
     {
+      # second time scale is not used so far --> set t3=t2=t
+      t2<-t; t3<-t
       calculateTask2(n,nMax,t,t2,t2max,t3,confidenceLevel,drift,equallySpacedTimesInput,secondTimeScaleIsUsedInput,
                      BoundsSymmetry, c(alpha1,alpha2), c(phi1,phi2), c(function1,function2),TruncateBoundsInput,
                     enterBoundsManually, upperBounds, lowerBounds, taskWindow )
@@ -1004,7 +1013,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   
   #Set Toplevel
   task2 <- tktoplevel(taskWindow)
-  tkwm.title(task2,"-2- Compute drift given power and bounds")
+  tkwm.title(task2,"-2- Compute Drift given Power and Bounds")
   
   #Define main Frame
   InputTask2 <- tkframe(task2, relief="groove",borderwidth=2)
@@ -1043,7 +1052,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   tkadd(nMenu,"command",label="23",command=function() onChangeInterimAnalyses(23))
   tkadd(nMenu,"command",label="24",command=function() onChangeInterimAnalyses(24))
   tkadd(nMenu,"command",label="25",command=function() onChangeInterimAnalyses(25))
-  tkadd(topMenu,"cascade",label=paste("#Interim times: K= ",as.character(n)),menu=nMenu)
+  tkadd(topMenu,"cascade",label=paste("#Interim Times: K= ",as.character(n)),menu=nMenu)
   
   tkgrid(tklabel(InputTask2,text="")) # Blank line
    
@@ -1114,7 +1123,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   tkconfigure(asymmetric,variable=SymmetryValue,value="3")
   
   #grid labels and buttons together
-  tkgrid(tklabel(boundsLabelFrame,text="One-, Two-sided symmetric or asymmetric bounds?"),sticky="w")
+  tkgrid(tklabel(boundsLabelFrame,text="One-, Two-sided-Symmetric or Asymmetric Bounds?"),sticky="w")
   tkgrid(tklabel(boundsRadioButtonFrame,text="One-Sided "),oneSided)
   tkgrid(tklabel(boundsRadioButtonFrame,text="Two-Sided "),twoSided)
   tkgrid(tklabel(boundsRadioButtonFrame,text="Asymmetric "),asymmetric)
@@ -1151,11 +1160,11 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   tkgrid.configure(manualBoundsCheckbox,sticky="w")
   
   #create labels for manual entering and grid alltogether
-  manualBoundsUPPERlabel<-tklabel(manualBoundsUPPERframe.Label,text="Enter UPPER Bounds(standarized)     ")
+  manualBoundsUPPERlabel<-tklabel(manualBoundsUPPERframe.Label,text="Enter UPPER Bounds (standardized)     ")
   tkgrid(manualBoundsUPPERlabel,sticky="w")
   tkgrid(manualBoundsUPPERframe.Label,sticky="w")
   tkgrid(manualBoundsUPPERframe.InputFields,sticky="w")
-  manualBoundsLOWERlabel<-tklabel(manualBoundsLOWERframe.Label,text="Enter LOWER Bounds (standarized)")
+  manualBoundsLOWERlabel<-tklabel(manualBoundsLOWERframe.Label,text="Enter LOWER Bounds (standardized)")
   tkgrid(manualBoundsLOWERlabel,sticky="w")
   tkgrid(manualBoundsLOWERframe.Label,sticky="w")
   tkgrid(manualBoundsLOWERframe.InputFields,sticky="w")
@@ -1188,7 +1197,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   functionLabel1of1<-tklabel(functionsFrame1of1,text="What function should be used?")
   listBoxFunction1of1<-tklistbox(functionsFrame1of1,height=5,width=30,selectmode="single",background="grey")
   functionChoice1of1 <- c("(1) O'Brien-Fleming Type","(2) Pocock Type",
-    "(3) Power family: alpha* t^phi","(4) Hwang-Shih-DeCani family","(5) Exact Pocock Bounds")
+    "(3) Power Family: alpha* t^phi","(4) Hwang-Shih-DeCani Family","(5) Exact Pocock Bounds")
   for (i in (1:5))
   {
     tkinsert(listBoxFunction1of1,"end",functionChoice1of1[i])
@@ -1254,7 +1263,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   functionLabel1of2<-tklabel(functionsFrame1of2,text="Choose Function for UPPER Bounds")
   listBoxFunction1of2<-tklistbox(functionsFrame1of2,height=5,width=30,selectmode="single",background="grey")
   functionChoice1of2 <- c("(1) O'Brien-Fleming Type","(2) Pocock Type",
-    "(3) Power family: alpha* t^phi","(4) Hwang-Shih-DeCani family","(5) Pocock - the real Pocock Bounds")
+    "(3) Power Family: alpha* t^phi","(4) Hwang-Shih-DeCani Family","(5) Exact Pocock Bounds")
   for (i in (1:5))
   {
     tkinsert(listBoxFunction1of2,"end",functionChoice1of2[i])
@@ -1273,7 +1282,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   functionLabel2of2<-tklabel(functionsFrame2of2,text="Choose Function for LOWER Bounds")
   listBoxFunction2of2<-tklistbox(functionsFrame2of2,height=5,width=30,selectmode="single",background="grey")
   functionChoice2of2 <- c("(1) O'Brien-Fleming Type","(2) Pocock Type",
-    "(3) Power family: alpha* t^phi","(4) Hwang-Shih-DeCani family","(5) Pocock - the real Pocock Bounds")
+    "(3) Power Family: alpha* t^phi","(4) Hwang-Shih-DeCani Family","(5) Exact Pocock Bounds")
   for (i in (1:5))
   {
     tkinsert(listBoxFunction2of2,"end",functionChoice2of2[i])
@@ -1337,7 +1346,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   entry.truncationValue <-tkentry(TruncateDynamicFrame,width="3",textvariable=boundsTruncation)
     
   #put frames
-  tkgrid(tklabel(TruncateLabelFrame,text="Truncate standarized Bounds?"),TruncateBoundsCheckBox)
+  tkgrid(tklabel(TruncateLabelFrame,text="Truncate standardized Bounds?"),TruncateBoundsCheckBox)
   tkgrid(boundsTruncationLabel,entry.truncationValue,sticky="w")
   tkgrid(TruncateLabelFrame,TruncateDynamicFrame,sticky="w")
   tkgrid(TruncateBoundsFrame,sticky="w")
